@@ -5,7 +5,7 @@
 $key = q/geq;MSF=1.5;AAT/;
 $cached_env_img{$key} = q|<IMG
  WIDTH="16" HEIGHT="27" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img1.png"
+ SRC="|."$dir".q|img1.gif"
  ALT="$ \geq$">|; 
 
 1;
